@@ -8,12 +8,14 @@ import java.awt.Graphics;
 import java.awt.Insets;
 import java.awt.Point;
 import java.awt.Rectangle;
+import java.awt.event.ActionEvent;
 import java.awt.event.MouseAdapter;
 import java.awt.event.MouseEvent;
 import java.awt.event.MouseListener;
 import java.awt.event.MouseMotionListener;
 import java.util.ArrayList;
 import java.util.List;
+import javax.swing.Action;
 import javax.swing.BoxLayout;
 import javax.swing.DefaultListCellRenderer;
 import javax.swing.JCheckBox;
@@ -44,6 +46,7 @@ import javax.swing.event.MouseInputAdapter;
  * @author   Mark Taylor
  * @since    13 Mar 2013
  */
+@SuppressWarnings({"unchecked","rawtypes"})
 public abstract class CheckBoxList<T> extends JList {
 
     private final Class<T> clazz_;
@@ -170,6 +173,23 @@ public abstract class CheckBoxList<T> extends JList {
         return getTypedValue( super.getSelectedValue() );
     }
 
+    /**
+     * Programmatically sets the checkbox status for all the items in the list.
+     *
+     * <p>The default implementation calls {@link #setChecked setChecked}
+     * for each item in the list, but subclasses may be able to
+     * override this for improved efficiency.
+     *
+     * @param  isChecked   true to check all, false to uncheck all
+     */
+    public void setCheckedAll( boolean isChecked ) {
+        ListModel model = getModel();
+        int nItem = model.getSize();
+        for ( int i = 0; i < nItem; i++ ) {
+            setChecked( (T) model.getElementAt( i ), isChecked );
+        }
+    }
+
     /**
      * Sets a message which is overpainted on the blank part of this
      * component.  If null or empty, no message is painted.
@@ -480,4 +500,22 @@ public abstract class CheckBoxList<T> extends JList {
             g.translate( -bounds.x, -bounds.y );
         }
     }
+
+    /**
+     * Returns a new action that can be used to check or uncheck all
+     * the items in the list at once.
+     *
+     * @param  isChecked   true to check all, false to uncheck all
+     */
+    public Action createCheckAllAction( final boolean isChecked ) {
+        String act = isChecked ? "Select" : "Unselect";
+        return new BasicAction( act + " All",
+                                isChecked ? ResourceIcon.REVEAL_ALL
+                                          : ResourceIcon.HIDE_ALL,
+                                act + " all the listed items" ) {
+            public void actionPerformed( ActionEvent evt ) {
+                setCheckedAll( isChecked );
+            }
+        };
+    }
 }
