@@ -9,7 +9,6 @@ import java.awt.event.KeyEvent;
 import java.awt.event.MouseEvent;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Iterator;
 import java.util.List;
 import java.util.logging.Logger;
 import javax.swing.AbstractAction;
@@ -65,6 +64,8 @@ public class ColumnInfoWindow extends AuxWindow {
     private final Action revealcolAct;
     private final Action hideallAct;
     private final Action revealallAct;
+    private final Action sortupAct;
+    private final Action sortdownAct;
     private final Action explodecolAct;
     private final ColumnInfo indexColumnInfo;
     private final JTable jtab;
@@ -95,7 +96,7 @@ public class ColumnInfoWindow extends AuxWindow {
         /* Assemble a list of MetaColumns which hold information about
          * the columns in the JTable this component will display.
          * Each column represents an item of metadata in the data table. */
-        List metas = new ArrayList();
+        List<MetaColumn> metas = new ArrayList<MetaColumn>();
 
         /* Add index column. */
         icolColsetIndex_ = metas.size();
@@ -168,6 +169,31 @@ public class ColumnInfoWindow extends AuxWindow {
                 return DefaultValueInfo
                       .formatShape( getColumnInfo( irow ).getShape() );
             }
+            public boolean isEditable( int irow ) {
+                return irow > 0 && getColumnInfo( irow ).isArray();
+            }
+            public void setValue( int irow, Object value ) {
+                ColumnInfo cinfo = getColumnInfo( irow );
+                int[] shape = null;
+                if ( cinfo.isArray() ) {
+                    shape = new int[] { -1 };
+                    String sval = value == null ? null : value.toString();
+                    if ( sval != null && sval.trim().length() > 0 ) {
+                        try {
+                            shape = DefaultValueInfo.unformatShape( sval );
+                        }
+                        catch ( RuntimeException e ) {
+                        }
+                    }
+                }
+                else {
+                    shape = null;
+                }
+                getColumnInfo( irow ).setShape( shape );
+                metaTableModel.fireTableRowsUpdated( irow, irow );
+                viewModel.fireTableDataChanged();
+                selectionUpdated();
+            }
         } );
 
         /* Add element size column. */
@@ -256,11 +282,26 @@ public class ColumnInfoWindow extends AuxWindow {
                 return getSyntheticColumn( irow ) != null;
             }
             public void setValue( int irow, Object value ) {
+                int icol = getModelIndexFromRow( irow );
+                String expr = (String) value;
+                if ( TopcatJELUtils
+                    .isColumnReferenced( tcModel, icol, expr ) ) {
+                     String[] msg = new String[] {
+                         "Recursive column expression disallowed:",
+                         "\"" + expr + "\"" +
+                         " directly or indirectly references column " + 
+                         dataModel.getColumnData( icol )
+                                  .getColumnInfo().getName(),
+                     };
+                     JOptionPane.showMessageDialog( ColumnInfoWindow.this, msg,
+                                                    "Expression Error",
+                                                    JOptionPane.ERROR_MESSAGE );
+                     return;
+                }
                 try { 
                     getSyntheticColumn( irow )
-                   .setExpression( (String) value, null,
-                                   tcModel.createJELRowReader() );
-                    super.setValue( irow, value );
+                   .setExpression( expr, null, tcModel.createJELRowReader() );
+                    super.setValue( irow, expr );
 
                     /* Message the table that its data may have changed.
                      * Since every cell in one column is changing, 
@@ -280,6 +321,7 @@ public class ColumnInfoWindow extends AuxWindow {
                     JOptionPane.showMessageDialog( ColumnInfoWindow.this, msg,
                                                    "Expression Syntax Error",
                                                    JOptionPane.ERROR_MESSAGE );
+                    return;
                 }
             }
         } );
@@ -344,7 +386,8 @@ public class ColumnInfoWindow extends AuxWindow {
         } );
 
         /* Get the list of aux metadata columns. */
-        List auxInfos = new ArrayList( dataModel.getColumnAuxDataInfos() );
+        List<ValueInfo> auxInfos =
+            new ArrayList<ValueInfo>( dataModel.getColumnAuxDataInfos() );
 
         /* Remove any from this list which we have already added explicitly
          * or otherwise don't want to show up. */
@@ -352,8 +395,8 @@ public class ColumnInfoWindow extends AuxWindow {
         auxInfos.remove( TopcatUtils.COLID_INFO );
         
         /* Add all the remaining aux columns. */
-        for ( Iterator it = auxInfos.iterator(); it.hasNext(); ) {
-            metas.add( new ValueInfoMetaColumn( (ValueInfo) it.next(), true ) );
+        for ( ValueInfo auxInfo : auxInfos ) {
+            metas.add( new ValueInfoMetaColumn( auxInfo, true ) );
         }
 
         /* Make a table model from the metadata columns.  This model has
@@ -370,7 +413,7 @@ public class ColumnInfoWindow extends AuxWindow {
 
         /* Construct and place a JTable to contain it. */
         jtab = new JTable( metaTableModel ) {
-            public TableCellRenderer getDefaultRenderer( Class clazz ) {
+            public TableCellRenderer getDefaultRenderer( Class<?> clazz ) {
                 if ( Boolean.class.equals( clazz ) ) {
                     return super.getDefaultRenderer( clazz );
                 }
@@ -474,8 +517,8 @@ public class ColumnInfoWindow extends AuxWindow {
                                               ResourceIcon.EXPLODE,
                                               "Replace N-element array column "
                                               + "with N scalar columns" );
-        final Action sortupAct = new SortAction( true );
-        final Action sortdownAct = new SortAction( false );
+        sortupAct = new SortAction( true );
+        sortdownAct = new SortAction( false );
         addcolAct.setEnabled( TopcatUtils.canJel() );
         replacecolAct.setEnabled( TopcatUtils.canJel() );
 
@@ -500,40 +543,13 @@ public class ColumnInfoWindow extends AuxWindow {
         getJMenuBar().add( displayMenu );
 
         /* Add a selection listener for menu items. */
-        ListSelectionListener selList = new ListSelectionListener() {
+        jtab.getSelectionModel()
+            .addListSelectionListener( new ListSelectionListener() {
             public void valueChanged( ListSelectionEvent evt ) {
-                int nsel = jtab.getSelectedRowCount();
-                boolean hasSelection = nsel > 0;
-                boolean hasUniqueSelection = nsel == 1;
-                if ( hasUniqueSelection &&
-                     toUnsortedIndex( jtab.getSelectedRow() ) == 0 ) {
-                    hasUniqueSelection = false;
-                    hasSelection = false;
-                }
-                boolean hasArraySelection;
-                if ( hasUniqueSelection ) {
-                    int iSel = toUnsortedIndex( jtab.getSelectedRow() );
-                    StarTableColumn tcol =
-                        (StarTableColumn) getColumnFromRow( iSel );
-                    int nel = getElementCount( tcol.getColumnInfo() );
-                    hasArraySelection = nel > 0;
-                    tcModel.fireModelChanged( TopcatEvent.COLUMN, tcol );
-                }
-                else {
-                    hasArraySelection = false;
-                }
-                hidecolAct.setEnabled( hasSelection );
-                revealcolAct.setEnabled( hasSelection );
-                explodecolAct.setEnabled( hasArraySelection );
-                sortupAct.setEnabled( hasUniqueSelection );
-                sortdownAct.setEnabled( hasUniqueSelection );
-                replacecolAct.setEnabled( hasUniqueSelection && 
-                                          TopcatUtils.canJel() );
+                selectionUpdated();
             }
-        };
-        ListSelectionModel selectionModel = jtab.getSelectionModel();
-        selectionModel.addListSelectionListener( selList );
-        selList.valueChanged( null );
+        } );
+        selectionUpdated();
 
         /* Add actions to the toolbar. */
         getToolBar().add( addcolAct );
@@ -668,6 +684,40 @@ public class ColumnInfoWindow extends AuxWindow {
         }
     }
 
+    /**
+     * Ensures that the GUI is in the correct state given that the
+     * currently selected JTable row (i.e. data model column) may
+     * have changed. 
+     */
+    private void selectionUpdated() {
+        int nsel = jtab.getSelectedRowCount();
+        boolean hasSelection = nsel > 0;
+        boolean hasUniqueSelection = nsel == 1;
+        if ( hasUniqueSelection &&
+             toUnsortedIndex( jtab.getSelectedRow() ) == 0 ) {
+            hasUniqueSelection = false;
+            hasSelection = false;
+        }
+        boolean hasArraySelection;
+        if ( hasUniqueSelection ) {
+            int iSel = toUnsortedIndex( jtab.getSelectedRow() );
+            StarTableColumn tcol =
+                (StarTableColumn) getColumnFromRow( iSel );
+            int nel = getElementCount( tcol.getColumnInfo() );
+            hasArraySelection = nel > 0;
+            tcModel.fireModelChanged( TopcatEvent.COLUMN, tcol );
+        }
+        else {
+            hasArraySelection = false;
+        }
+        hidecolAct.setEnabled( hasSelection );
+        revealcolAct.setEnabled( hasSelection );
+        explodecolAct.setEnabled( hasArraySelection );
+        sortupAct.setEnabled( hasUniqueSelection );
+        sortdownAct.setEnabled( hasUniqueSelection );
+        replacecolAct.setEnabled( hasUniqueSelection && TopcatUtils.canJel() );
+    }
+
     /**
      * Returns the number of elements per cell in a ValueInfo.
      * The result is a positive integer only if the info represents an
@@ -716,7 +766,7 @@ public class ColumnInfoWindow extends AuxWindow {
 
         private ValueInfo vinfo;
         private boolean isEditable;
-        private Class vclass;
+        private Class<?> vclass;
         private boolean isFormattable;
 
         ValueInfoMetaColumn( ValueInfo vinfo, boolean isEditable ) {
@@ -778,7 +828,7 @@ public class ColumnInfoWindow extends AuxWindow {
      * @return   true if String format/unformat is implemented
      */
     private static boolean canFormat( ValueInfo info ) {
-        Class clazz = info.getContentClass();
+        Class<?> clazz = info.getContentClass();
         return Number.class.isAssignableFrom( clazz )
             || String.class.isAssignableFrom( clazz )
             || Boolean.class.isAssignableFrom( clazz );
