@@ -68,6 +68,7 @@ import javax.swing.ListModel;
 import javax.swing.SwingUtilities;
 import javax.swing.Timer;
 import javax.swing.TransferHandler;
+import javax.swing.UIManager;
 import javax.swing.WindowConstants;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ListDataEvent;
@@ -84,6 +85,7 @@ import javax.swing.event.TableModelListener;
 import javax.swing.table.TableColumnModel;
 import org.astrogrid.samp.client.DefaultClientProfile;
 import uk.ac.starlink.plastic.PlasticUtils;
+import uk.ac.starlink.table.DescribedValue;
 import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.table.StarTableFactory;
 import uk.ac.starlink.table.StarTableOutput;
@@ -91,6 +93,7 @@ import uk.ac.starlink.table.StoragePolicy;
 import uk.ac.starlink.table.TableSequence;
 import uk.ac.starlink.table.TableSink;
 import uk.ac.starlink.table.Tables;
+import uk.ac.starlink.table.ValueInfo;
 import uk.ac.starlink.table.jdbc.TextModelsAuthenticator;
 import uk.ac.starlink.table.gui.TableLoadClient;
 import uk.ac.starlink.table.gui.TableLoadDialog;
@@ -128,6 +131,7 @@ import uk.ac.starlink.util.gui.ErrorDialog;
 import uk.ac.starlink.util.gui.MemoryMonitor;
 import uk.ac.starlink.util.gui.StringPaster;
 import uk.ac.starlink.vo.DalLoader;
+import uk.ac.starlink.vo.DalTableLoadDialog;
 import uk.ac.starlink.vo.SkyDalTableLoadDialog;
 import uk.ac.starlink.vo.SkyPositionEntry;
 
@@ -145,6 +149,7 @@ import uk.ac.starlink.vo.SkyPositionEntry;
  * @author   Mark Taylor (Starlink)
  * @since    9 Mar 2004
  */
+@SuppressWarnings({"unchecked","rawtypes","deprecation"})
 public class ControlWindow extends AuxWindow
                            implements ListSelectionListener, 
                                       ListDataListener,
@@ -198,12 +203,14 @@ public class ControlWindow extends AuxWindow
     private CdsUploadMatchWindow cdsmatchWindow_;
     private ExtApp extApp_;
     private TopcatModel currentModel_;
+    private int iPlotwin_;
 
     private final JTextField idField_ = new JTextField();
     private final JLabel indexLabel_ = new JLabel();
     private final JLabel locLabel_ = new JLabel();
     private final JLabel nameLabel_ = new JLabel();
     private final JLabel rowsLabel_ = new JLabel();
+    private final JLabel qstatusLabel_ = new JLabel();
     private final JLabel colsLabel_ = new JLabel();
     private final JComboBox subsetSelector_ = new JComboBox();
     private final JComboBox sortSelector_ = new JComboBox();
@@ -260,12 +267,18 @@ public class ControlWindow extends AuxWindow
         } );
 
         /* Set up a panel displaying table information. */
+        JComponent rowsLine = Box.createHorizontalBox();
+        rowsLine.add( rowsLabel_ );
+        rowsLine.add( Box.createHorizontalStrut( 5 ) );
+        rowsLine.add( qstatusLabel_ );
+        qstatusLabel_.setForeground( UIManager
+                                    .getColor( "Label.disabledForeground" ) );
         InfoStack info = new InfoStack();
         info.setBorder( BorderFactory.createEmptyBorder( 4, 4, 4, 4 ) );
         info.addLine( "Label", idField_ );
         info.addLine( "Location", locLabel_ );
         info.addLine( "Name", nameLabel_ );
-        info.addLine( "Rows", rowsLabel_ );
+        info.addLine( "Rows", rowsLine );
         info.addLine( "Columns", colsLabel_ );
         info.addLine( "Sort Order", new Component[] { sortSenseButton_,
                                                       sortSelector_ } );
@@ -372,19 +385,24 @@ public class ControlWindow extends AuxWindow
         final ModelViewAction viewerAct;
         viewActs_ = new ModelViewAction[] {
             viewerAct =
-            new ModelViewWindowAction( "Table Data", ResourceIcon.VIEWER,
+            new ModelViewWindowAction<TableViewerWindow>
+                                     ( "Table Data", ResourceIcon.VIEWER,
                                        "Display table cell data",
                                        TableViewerWindow.class ),
-            new ModelViewWindowAction( "Table Parameters", ResourceIcon.PARAMS,
+            new ModelViewWindowAction<ParameterWindow>
+                                     ( "Table Parameters", ResourceIcon.PARAMS,
                                        "Display table metadata",
                                        ParameterWindow.class ),
-            new ModelViewWindowAction( "Column Info", ResourceIcon.COLUMNS,
+            new ModelViewWindowAction<ColumnInfoWindow>
+                                     ( "Column Info", ResourceIcon.COLUMNS,
                                        "Display column metadata",
                                        ColumnInfoWindow.class ),
-            new ModelViewWindowAction( "Row Subsets", ResourceIcon.SUBSETS,
+            new ModelViewWindowAction<SubsetWindow>
+                                     ( "Row Subsets", ResourceIcon.SUBSETS,
                                        "Display row subsets",
                                        SubsetWindow.class ),
-            new ModelViewWindowAction( "Column Statistics", ResourceIcon.STATS,
+            new ModelViewWindowAction<StatsWindow>
+                                     ( "Column Statistics", ResourceIcon.STATS,
                                        "Display statistics for each column",
                                        StatsWindow.class ),
             new ActivationWindowAction( "Activation Actions",
@@ -392,7 +410,8 @@ public class ControlWindow extends AuxWindow
                                         "Display actions invoked when rows "
                                       + "are selected" ),
             datalinkAct_ =
-            new ModelViewWindowAction( "DataLink View", ResourceIcon.DATALINK,
+            new ModelViewWindowAction<DatalinkWindow>
+                                     ( "DataLink View", ResourceIcon.DATALINK,
                                        "Show row data as a DataLink table",
                                        DatalinkWindow.class ),
         };
@@ -668,19 +687,17 @@ public class ControlWindow extends AuxWindow
             }
             public void menuSelected( MenuEvent evt ) {
                 voMenu.removeMenuListener( this );
-                Class[] tldClasses = new Class[] {
-                    TopcatConeSearchDialog.class,
-                    TopcatSiapTableLoadDialog.class,
-                    TopcatSsapTableLoadDialog.class,
-                    TopcatTapTableLoadDialog.class,
-                    VizierTableLoadDialog.class,
-                    GavoTableLoadDialog.class,
-                    BaSTITableLoadDialog.class,
-                };
+                List<Class<? extends TableLoadDialog>> tldClasses =
+                    new ArrayList<Class<? extends TableLoadDialog>>();
+                tldClasses.add( TopcatConeSearchDialog.class );
+                tldClasses.add( TopcatSiapTableLoadDialog.class );
+                tldClasses.add( TopcatSsapTableLoadDialog.class );
+                tldClasses.add( TopcatTapTableLoadDialog.class );
+                tldClasses.add( VizierTableLoadDialog.class );
+                tldClasses.add( GavoTableLoadDialog.class );
+                tldClasses.add( BaSTITableLoadDialog.class );
                 LoadWindow loadWin = getLoadWindow();
-                for ( int ic = 0; ic < tldClasses.length; ic++ ) {
-                    Class clazz = tldClasses[ ic ];
-                    assert TableLoadDialog.class.isAssignableFrom( clazz );
+                for ( Class<? extends TableLoadDialog> clazz : tldClasses ) {
                     Action act = loadWin.getDialogAction( clazz );
                     assert act != null;
                     voMenu.add( act );
@@ -822,10 +839,10 @@ public class ControlWindow extends AuxWindow
     public void moveCurrent( boolean up ) {
         ListSelectionModel selModel = tablesList_.getSelectionModel();
         int iFrom = selModel.getMinSelectionIndex();
-        TopcatModel tcFrom = (TopcatModel) tablesModel_.get( iFrom );
+        TopcatModel tcFrom = tablesModel_.getElementAt( iFrom );
         int iTo = iFrom + ( up ? -1 : +1 );
         int iLo = iFrom + ( up ? -1 : 0 );
-        tablesModel_.insertElementAt( (TopcatModel) tablesModel_.get( iLo ),
+        tablesModel_.insertElementAt( tablesModel_.getElementAt( iLo ),
                                       iLo + 2 );
         tablesModel_.remove( iLo );
         assert tablesModel_.get( iTo ) == tcFrom;
@@ -1176,7 +1193,8 @@ public class ControlWindow extends AuxWindow
      * @param  tld  load dialogue
      * @param  tldClass  load dialogue type
      */
-    public boolean loadDialogMatches( TableLoadDialog tld, Class tldClass ) {
+    public boolean
+            loadDialogMatches( TableLoadDialog tld, Class<?> tldClass ) {
         return tldClass != null && tldClass.isAssignableFrom( tld.getClass() );
     }
 
@@ -1184,7 +1202,9 @@ public class ControlWindow extends AuxWindow
      * Indicates whether the given multi window is of the type indicated
      * by the given class.
      */
-    public boolean multiWindowMatches( DalMultiWindow mw, Class mwClass ) {
+    public boolean
+        multiWindowMatches( DalMultiWindow mw,
+                            Class<? extends DalMultiWindow> mwClass ) {
         return mwClass != null && mwClass.isAssignableFrom( mw.getClass() );
     }
 
@@ -1222,7 +1242,7 @@ public class ControlWindow extends AuxWindow
                 System.exit( 0 );
             }
             else {
-                for ( Enumeration en = tablesModel_.elements();
+                for ( Enumeration<?> en = tablesModel_.elements();
                       en.hasMoreElements(); ) {
                     removeTable( (TopcatModel) en.nextElement() );
                 }
@@ -1264,6 +1284,7 @@ public class ControlWindow extends AuxWindow
                               ? ""
                               : " (" + TopcatUtils.formatLong( visRows )
                                      + " apparent)" ) );
+            qstatusLabel_.setText( getQueryStatus( dataModel ) );
             colsLabel_.setText( totCols +
                                 ( ( visCols == totCols )
                                             ? ""
@@ -1430,6 +1451,57 @@ public class ControlWindow extends AuxWindow
         updateControls();
     }
 
+    /**
+     * Returns a string giving additional query status information for a
+     * given table.  This extracts information that may have been present in
+     * DALI-style INFO/@name="QUERY_STATUS" nodes in the original VOTable
+     * and flattens them into a user-readable form.  An empty string
+     * is returned if there's nothing to say (table apparently loaded OK).
+     * The return value is (just about) always an empty string for
+     * tables that have not originated from a VOTable source.
+     *
+     * <p>This is not bulletproof - table parameters named QUERY_STATUS
+     * originating from some source other than a DALI-compliant INFO
+     * could also show up here.  But it's unlikely to happen often.
+     *
+     * @param  table  table
+     * @return  query status string; may be empty, but not null
+     * @see   <a href="http://www.ivoa.net/documents/DALI/">DALI</a>
+     */
+    private static String getQueryStatus( StarTable table ) {
+        for ( DescribedValue dval : table.getParameters() ) {
+            ValueInfo info = dval.getInfo();
+            if ( "QUERY_STATUS".equals( info.getName() ) ) {
+                Object vobj = dval.getValue();
+
+                /* According to DALI, the only values of interest here
+                 * would be OVERFLOW and ERROR.  However, if something
+                 * else other than OK is present, it's probably worth
+                 * reporting anyway; most likely it's a misspelling or
+                 * something, that the user may be able to make of. */
+                if ( vobj instanceof String ) {
+                    String status = ((String) vobj).trim();
+                    if ( ! "OK".equals( status ) &&
+                         status.length() > 0 ) {
+                        StringBuffer sbuf = new StringBuffer()
+                            .append( " " )
+                            .append( "(" )
+                            .append( status );
+                        String descrip = info.getDescription();
+                        if ( descrip != null &&
+                             descrip.trim().length() > 0 ) {
+                            sbuf.append( ": " )
+                                .append( descrip.trim() );
+                        }
+                        sbuf.append( ")" );
+                        return sbuf.toString();
+                    }
+                }
+            }
+        }
+        return "";
+    }
+
     /**
      * Constructs a new TopcatCommunicator.
      * The implementation used is determined by the value of the 
@@ -1517,7 +1589,7 @@ public class ControlWindow extends AuxWindow
                     msg = "Remove table " + tcModels[ 0 ] + " from list?";
                 }
                 else {
-                    List msgList = new ArrayList();
+                    List<String> msgList = new ArrayList<String>();
                     msgList.add( "Remove tables from list?" );
                     for ( int i = 0; i < nt; i++ ) {
                         msgList.add( "    " + tcModels[ i ] );
@@ -1601,12 +1673,14 @@ public class ControlWindow extends AuxWindow
     /**
      * ModelViewAction class for actions which pop up a view window.
      */
-    private class ModelViewWindowAction extends BasicAction
-                                        implements ModelViewAction {
+    private class ModelViewWindowAction<W extends AuxWindow>
+            extends BasicAction
+            implements ModelViewAction {
 
-        AuxWindow window_;
-        final Constructor constructor_;
-        private final Map modelWindows_ = new WeakHashMap();
+        W window_;
+        final Constructor<W> constructor_;
+        private final Map<TopcatModel,W> modelWindows_ =
+            new WeakHashMap<TopcatModel,W>();
 
         /**
          * Constructor.
@@ -1618,13 +1692,10 @@ public class ControlWindow extends AuxWindow
          *         constructor that takes (TopcatModel,Component).
          */
         ModelViewWindowAction( String name, Icon icon, String shortdesc,
-                               Class winClass ) {
+                               Class<W> winClass ) {
             super( name, icon, shortdesc );
-            if ( ! AuxWindow.class.isAssignableFrom( winClass ) ) {
-                throw new IllegalArgumentException();
-            }
             try {
-                constructor_ = winClass.getConstructor( new Class[] {
+                constructor_ = winClass.getConstructor( new Class<?>[] {
                     TopcatModel.class, Component.class,
                 } );
             }
@@ -1644,7 +1715,7 @@ public class ControlWindow extends AuxWindow
             if ( tcModel == null ) {
                 return;
             }
-            Window window = (Window) modelWindows_.get( tcModel );
+            W window = modelWindows_.get( tcModel );
             if ( window == null ) {
                 window = createWindow( tcModel );
                 modelWindows_.put( tcModel, window );
@@ -1653,7 +1724,7 @@ public class ControlWindow extends AuxWindow
         }
 
         public void setViewVisible( TopcatModel tcModel, boolean visible ) {
-            Window window = (Window) modelWindows_.get( tcModel );
+            W window = modelWindows_.get( tcModel );
             if ( window != null ) {
                 if ( visible ) {
                     window.setVisible( true );
@@ -1669,11 +1740,11 @@ public class ControlWindow extends AuxWindow
          *
          * @param  tcModel  table the window will apply to
          */
-        private Window createWindow( TopcatModel tcModel ) {
+        private W createWindow( TopcatModel tcModel ) {
             try {
                 Object[] args = new Object[] { tcModel, ControlWindow.this };
                 try {
-                    return (AuxWindow) constructor_.newInstance( args );
+                    return constructor_.newInstance( args );
                 }
                 catch ( InvocationTargetException e ) {
                     throw e.getCause();
@@ -1776,8 +1847,9 @@ public class ControlWindow extends AuxWindow
         }
 
         public void actionPerformed( ActionEvent evt ) {
-            StackPlotWindow window =
+            StackPlotWindow<?,?> window =
                 ptype_.createWindow( plot2parent_, tablesModel_ );
+            window.setTitle( ptype_.getName() + " Plot (" + ++iPlotwin_ + ")" );
             TopcatModel tcModel = getCurrentModel();
             Control dfltControl =
                 window.getControlManager().createDefaultControl( tcModel );
@@ -1823,8 +1895,7 @@ public class ControlWindow extends AuxWindow
             int ntab = tablesModel_.getSize();
             for ( int i = 0; i < ntab; i++ ) {
                 boolean isSelected = tablesList_.isSelectedIndex( i );
-                TopcatModel tcModel = 
-                    (TopcatModel) tablesModel_.getElementAt( i );
+                TopcatModel tcModel = tablesModel_.getElementAt( i );
                 Object effect = isSelected ? selEffect : otherEffect;
                 if ( effect == WindowEffect.HIDE ) {
                     setViewsVisible( tcModel, false );
