@@ -109,6 +109,8 @@ public class ResourceIcon implements Icon {
         REVEAL = makeIcon( "true.png" ),
         HIDE_ALL = makeIcon( "falseAll2.png" ),
         REVEAL_ALL = makeIcon( "trueAll2.png" ),
+        HIDE_ALL_TINY = makeIcon( "falseAllTiny.png" ),
+        REVEAL_ALL_TINY = makeIcon( "trueAllTiny.png" ),
         MODIFY = makeIcon( "redo3.png" ),
         SEARCH = makeIcon( "search2.png" ),
         LOG = makeIcon( "book3.png" ),
@@ -152,13 +154,15 @@ public class ResourceIcon implements Icon {
         REACTIVATE_ALL = makeIcon( "flash-2d.png" ),
         ACTIVATE_SEQ = makeIcon( "flash1seq.png" ),
         ACTIVATE_SEQ_ALL = makeIcon( "flash2seq.png" ),
-        CANCEL_SEQ = makeIcon( "noseq.png" ),
+        PAUSE_SEQ = makeIcon( "pauseseq.png" ),
+        CANCEL_SEQ = makeIcon( "stopseq.png" ),
         DELETE_INACTIVE = makeIcon( "trash2-box.png" ),
 
         /* Specific actions. */
         UNSORT = makeIcon( "arrow_level.png" ),
         DELETE_COLUMN = makeIcon( "ColumnDelete24.png" ),
         VISIBLE_SUBSET = makeIcon( "spoints5.png" ),
+        JEL_VISIBLE_SUBSET = makeIcon( "jelvis.png" ),
         RANGE_SUBSET = makeIcon( "sbars0.png" ),
         XRANGE_SUBSET = makeIcon( "xrange1.png" ),
         BLOB_SUBSET = makeIcon( "blob2.png" ),
@@ -248,12 +252,14 @@ public class ResourceIcon implements Icon {
         HISTO_IMPORT = makeIcon( "histo-import.png" ),
         WARNING = makeIcon( "warning_triangle.png" ),
         APPROVE_ALL = makeIcon( "approve_all.png" ),
+        MEASURE = makeIcon( "measure.png" ),
 
         /* Plot2 icons. */
         UP_DOWN = makeIcon( "updown8.png" ),
         FLOAT = makeIcon( "float1.png" ),
         PLOT_DATA = makeIcon( "dataplot.png" ),
         PLOT_PAIR = makeIcon( "pairplot.png" ),
+        PLOT_QUAD = makeIcon( "quadplot.png" ),
         PLOT_HISTO = makeIcon( "histoplot.png" ),
         PLOT2_PLANE = makeIcon( "plot2plane.png" ),
         PLOT2_SKY = makeIcon( "plot2sky.png" ),
@@ -637,6 +643,7 @@ public class ResourceIcon implements Icon {
      *
      * @return  member name => member value mapping for hand-drawn icons
      */
+    @SuppressWarnings("static")
     private static Map<String,Icon> getDiyIconMap() {
         Map<String,Icon> nameMap = new LinkedHashMap<String,Icon>();
         ErrorModeSelectionModel errX = new ErrorModeSelectionModel( 0, "X" );
@@ -681,11 +688,11 @@ public class ResourceIcon implements Icon {
                         .getResource( "plaf/basic/images/SearchNav.gif" ) ) );
 
         /* Pull in icons from external packages. */
-        Class[] riClazzes = new Class[] {
+        Class<?>[] riClazzes = new Class<?>[] {
             uk.ac.starlink.ttools.gui.ResourceIcon.class,
             uk.ac.starlink.vo.ResourceIcon.class,
         };
-        for ( Class riClazz : riClazzes ) {
+        for ( Class<?> riClazz : riClazzes ) {
             Field[] fields = riClazz.getDeclaredFields();
             for ( int i = 0; i < fields.length; i++ ) {
                 Field field = fields[ i ];
@@ -713,6 +720,7 @@ public class ResourceIcon implements Icon {
             uk.ac.starlink.ttools.gui.ResourceIcon.REF;
         putMap( nameMap, "ADD_PLOT_DATA", toAddIcon( PLOT_DATA ) );
         putMap( nameMap, "ADD_PLOT_PAIR", toAddIcon( PLOT_PAIR ) );
+        putMap( nameMap, "ADD_PLOT_QUAD", toAddIcon( PLOT_QUAD ) );
         putMap( nameMap, "ADD_PLOT_HISTO", toAddIcon( PLOT_HISTO ) );
         putMap( nameMap, "ADD_FORM_MARK", toAddIcon( TTRI.FORM_MARK ) );
         putMap( nameMap, "ADD_FORM_SIZE", toAddIcon( TTRI.FORM_SIZE ) );
@@ -900,7 +908,7 @@ public class ResourceIcon implements Icon {
             }
         }
         else if ( "-entities".equals( mode ) ) {
-            Map iconMap = getMemberNameMap();
+            Map<String,ResourceIcon> iconMap = getMemberNameMap();
             String t1 = "  <!ENTITY IMG.";
             String t2 = " '<img src=\"../" + PREFIX;
             String t3 = "\"/>'>";
@@ -924,7 +932,6 @@ public class ResourceIcon implements Icon {
             }
         }
         else if ( "-writepngs".equals( mode ) ) {
-            Map diyMap = getDiyIconMap();
             for ( Map.Entry<String,Icon> entry : getDiyIconMap().entrySet() ) {
                 writePng( entry.getValue(),
                           new File( entry.getKey() + ".png" ) );
