@@ -44,7 +44,7 @@ public class SubsetWindow extends AuxWindow implements ListDataListener {
 
     private final TopcatModel tcModel;
     private final OptionsListModel<RowSubset> subsets;
-    private final Map subsetCounts;
+    private final Map<RowSubset,Long> subsetCounts;
     private final PlasticStarTable dataModel;
     private final MetaColumnTableModel subsetsTableModel;
     private final ToggleButtonModel autoCountModel;
@@ -250,6 +250,7 @@ public class SubsetWindow extends AuxWindow implements ListDataListener {
                 if ( rset != null ) {
                     selectionModel.setValueIsAdjusting( true );
                     selectionModel.clearSelection();
+                    @SuppressWarnings("rawtypes")
                     ComboBoxModel tcSelModel = 
                         tcModel.getSubsetSelectionModel();
                     for ( int irow = 0; irow < subsetsTableModel.getRowCount();
@@ -379,7 +380,7 @@ public class SubsetWindow extends AuxWindow implements ListDataListener {
             }
             public Object getValue( int irow ) {
                 RowSubset rset = getSubset( irow );
-                Number count = (Number) subsetCounts.get( rset );
+                Long count = subsetCounts.get( rset );
                 return count == null
                      ? null
                      : fmt.format( count.doubleValue()
@@ -402,8 +403,23 @@ public class SubsetWindow extends AuxWindow implements ListDataListener {
                 return getSubset( irow ) instanceof SyntheticRowSubset;
             }
             public void setValue( int irow, Object value ) {
+                String expr = value.toString();
                 SyntheticRowSubset rset =
                    (SyntheticRowSubset) getSubset( irow );
+                int rsetId = subsets.indexToId( irow );
+                if ( TopcatJELUtils
+                    .isSubsetReferenced( tcModel, rsetId, expr ) ) {
+                    String[] msg = new String[] {
+                        "Recursive subset expression disallowed:",
+                        "\"" + expr + "\"" +
+                        " directly or indirectly references subset " +
+                        rset.getName(),
+                    };
+                    JOptionPane.showMessageDialog( SubsetWindow.this, msg,
+                                                   "Expression Error",
+                                                   JOptionPane.ERROR_MESSAGE );
+                    return;
+                }
                 try {
                     rset.setExpression( value.toString(),
                                         tcModel.createJELRowReader() );
@@ -421,7 +437,10 @@ public class SubsetWindow extends AuxWindow implements ListDataListener {
                 }
                 subsetCounts.remove( rset );
                 subsets.set( irow, rset );
-                tcModel.getViewModel().fireTableDataChanged();
+                if ( tcModel.getSubsetSelectionModel().getSelectedItem()
+                     == rset ) {
+                    tcModel.getViewModel().setSubset( rset );
+                }
             }
         };
 
@@ -442,7 +461,7 @@ public class SubsetWindow extends AuxWindow implements ListDataListener {
         };
 
         /* Make a TableModel from these columns. */
-        List cols = new ArrayList();
+        List<MetaColumn> cols = new ArrayList<MetaColumn>();
         cols.add( idCol );
         cols.add( nameCol );
         cols.add( sizeCol );
@@ -524,7 +543,7 @@ public class SubsetWindow extends AuxWindow implements ListDataListener {
      */
     private Object getSubsetSize( int irow ) {
         RowSubset rset = getSubset( irow );
-        Number count = (Number) subsetCounts.get( rset );
+        Long count = subsetCounts.get( rset );
         if ( count == null || count.longValue() < 0 ) {
 
             /* If the value is unknown and autocount mode is on, then kick
