@@ -15,12 +15,12 @@ import uk.ac.starlink.table.DescribedValue;
 import uk.ac.starlink.table.gui.LabelledComponentStack;
 import uk.ac.starlink.table.gui.StarTableColumn;
 import uk.ac.starlink.table.gui.UCDSelector;
-import uk.ac.starlink.util.gui.CustomComboBoxRenderer;
 
 /**
  * A dialogue window which queries the user for the characteristics of a
  * new column and then appends it to the table.
  */
+@SuppressWarnings({"unchecked","rawtypes"})
 public class SyntheticColumnQueryWindow extends QueryWindow {
 
     private final TopcatModel tcModel;
@@ -75,9 +75,7 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
         typeField.addItem( long.class );
         typeField.addItem( float.class );
         typeField.addItem( double.class );
-        CustomComboBoxRenderer renderer = new ClassComboBoxRenderer();
-        renderer.setNullRepresentation( "(auto)" );
-        typeField.setRenderer( renderer );
+        typeField.setRenderer( new ClassComboBoxRenderer( "(auto)" ) );
         typeField.setSelectedIndex( 0 );
 
         // Don't add this option for now - it's not that useful, since
@@ -198,7 +196,7 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
      *
      * @param   clazz  forced expression type, or null
      */
-    public void setExpressionType( Class clazz ) {
+    public void setExpressionType( Class<?> clazz ) {
         typeField.setSelectedItem( clazz );
     }
 
@@ -208,8 +206,8 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
      *
      * @return  forced expression type, or null
      */
-    public Class getExpressionType() {
-        return (Class) typeField.getSelectedItem();
+    public Class<?> getExpressionType() {
+        return (Class<?>) typeField.getSelectedItem();
     }
 
     /**
@@ -234,7 +232,7 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
         String unit = getUnit();
         String expr = getExpression();
         String ucd = getUCD();
-        Class clazz = getExpressionType();
+        Class<?> clazz = getExpressionType();
         ColumnInfo info = new ColumnInfo( name );
         if ( desc != null ) {
             info.setDescription( desc );
