@@ -283,13 +283,10 @@ public class TopcatCodec2 implements TopcatCodec {
 
         /* Copy parameters from the input table.
          * Be paranoid about possible name clashes. */
-        for ( Object item : dataModel.getParameters() ) {
-            if ( item instanceof DescribedValue ) {
-                DescribedValue dval = (DescribedValue) item;
-                String utype = dval.getInfo().getUtype();
-                if ( ! isCodecUtype( utype ) ) {
-                    paramList.add( dval );
-                }
+        for ( DescribedValue dval : dataModel.getParameters() ) {
+            String utype = dval.getInfo().getUtype();
+            if ( ! isCodecUtype( utype ) ) {
+                paramList.add( dval );
             }
         }
 
@@ -560,7 +557,7 @@ public class TopcatCodec2 implements TopcatCodec {
             String expr = colExprs[ ic ];
             if ( expr != null ) {
                 ColumnInfo info = dataModel.getColumnInfo( ic );
-                Class clazz = info.getContentClass();
+                Class<?> clazz = info.getContentClass();
                 RandomJELRowReader rowReader = tcModel.createJELRowReader();
                 try {
                     ColumnData cdata =
@@ -695,7 +692,7 @@ public class TopcatCodec2 implements TopcatCodec {
     private RowSubset createRowSubset( String name, final StarTable table,
                                        final int icol, int iflag ) {
         ColumnInfo info = table.getColumnInfo( icol );
-        Class clazz = info.getContentClass();
+        Class<?> clazz = info.getContentClass();
         if ( clazz == Short.class ) {
             final short mask = (short) ( 1 << iflag );
             return new RowSubset( name ) {
@@ -787,7 +784,7 @@ public class TopcatCodec2 implements TopcatCodec {
      * @param   clazz  class of value which will be stored under this item
      * @return   new metadata description object
      */
-    private static ValueInfo createCodecInfo( String name, Class clazz ) {
+    private static ValueInfo createCodecInfo( String name, Class<?> clazz ) {
         DefaultValueInfo info =
             new DefaultValueInfo( CODEC_NAME_PREFIX + name, clazz );
         info.setUtype( CODEC_UTYPE_PREFIX + name ); 
@@ -882,16 +879,13 @@ public class TopcatCodec2 implements TopcatCodec {
              * for later retrieval.  These parameters should all have
              * custom and easily-identifiable topcat-specific utypes. */
             codecParamMap_ = new LinkedHashMap<String,DescribedValue>();
-            for ( Object item : params ) {
-                if ( item instanceof DescribedValue ) {
-                    DescribedValue dval = (DescribedValue) item;
-                    String utype = dval.getInfo().getUtype();
-                    if ( isCodecUtype( utype ) ) {
-                        codecParamMap_.put( utype, dval );
-                    }
-                    else {
-                        dataParamList_.add( dval );
-                    }
+            for ( DescribedValue dval : params ) {
+                String utype = dval.getInfo().getUtype();
+                if ( isCodecUtype( utype ) ) {
+                    codecParamMap_.put( utype, dval );
+                }
+                else {
+                    dataParamList_.add( dval );
                 }
             }
         }
@@ -936,7 +930,7 @@ public class TopcatCodec2 implements TopcatCodec {
              * but we need to return the value in the form requested
              * by the supplied info argument, since it will get cast 
              * to that class. */
-            Class infoClazz = info.getContentClass();
+            Class<?> infoClazz = info.getContentClass();
             if ( value == null || infoClazz.isInstance( value ) ) {
                 return value;
             }
