@@ -51,6 +51,8 @@ import javax.swing.SwingUtilities;
 import javax.swing.UIManager;
 import javax.swing.border.Border;
 import javax.swing.border.TitledBorder;
+import javax.swing.event.ChangeEvent;
+import javax.swing.event.ChangeListener;
 import javax.swing.event.ListDataEvent;
 import javax.swing.event.ListDataListener;
 import javax.swing.event.ListSelectionEvent;
@@ -62,6 +64,7 @@ import uk.ac.starlink.topcat.LineBox;
 import uk.ac.starlink.topcat.MethodWindow;
 import uk.ac.starlink.topcat.ResourceIcon;
 import uk.ac.starlink.topcat.Safety;
+import uk.ac.starlink.topcat.ToggleButtonModel;
 import uk.ac.starlink.topcat.TopcatEvent;
 import uk.ac.starlink.topcat.TopcatModel;
 import uk.ac.starlink.topcat.ViewerTableModel;
@@ -73,6 +76,7 @@ import uk.ac.starlink.util.Loader;
  * @author   Mark Taylor
  * @since    21 Dec 2017
  */
+@SuppressWarnings({"unchecked","rawtypes"})
 public class ActivationWindow extends AuxWindow {
 
     private final TopcatModel tcModel_;
@@ -91,6 +95,7 @@ public class ActivationWindow extends AuxWindow {
     private final AllSequenceAction allSeqAct_;
     private final CancelSequenceAction cancelSeqAct_;
     private final ApproveAllAction approveAllAct_;
+    private final SequencePauser seqPauser_;
     private final ActionListener statusListener_;
     private final JProgressBar progBar_;
     private final ThreadFactory seqThreadFact_;
@@ -123,6 +128,7 @@ public class ActivationWindow extends AuxWindow {
      * @param  tcModel  topcat model
      * @param  parent  parent window, may be used for positioning
      */
+    @SuppressWarnings("fallthrough")
     public ActivationWindow( final TopcatModel tcModel, Component parent ) {
         super( tcModel, "Activation Actions", parent );
         tcModel_ = tcModel;
@@ -317,6 +323,8 @@ public class ActivationWindow extends AuxWindow {
         allSeqAct_ = new AllSequenceAction();
         cancelSeqAct_ = new CancelSequenceAction();
         approveAllAct_ = new ApproveAllAction();
+        seqPauser_ = new SequencePauser();
+        ToggleButtonModel pauseModel = seqPauser_.model_;
 
         list_.addListSelectionListener( new ListSelectionListener() {
             public void valueChanged( ListSelectionEvent evt ) {
@@ -444,6 +452,7 @@ public class ActivationWindow extends AuxWindow {
         actMenu.addSeparator();
         actMenu.add( singleSeqAct_ );
         actMenu.add( allSeqAct_ );
+        actMenu.add( pauseModel.createMenuItem() );
         actMenu.add( cancelSeqAct_ );
 
         /* Add tools. */
@@ -457,6 +466,7 @@ public class ActivationWindow extends AuxWindow {
         toolbar.addSeparator();
         toolbar.add( singleSeqAct_ );
         toolbar.add( allSeqAct_ );
+        toolbar.add( pauseModel.createToolbarButton() );
         toolbar.add( cancelSeqAct_ );
         toolbar.addSeparator();
         toolbar.add( MethodWindow.getWindowAction( this, true ) );
@@ -634,6 +644,26 @@ public class ActivationWindow extends AuxWindow {
         }
     }
 
+    /**
+     * Updates the currently active row in the topcat model served
+     * by this activation window.  In most cases, it's not necessary
+     * to call this, since the activation actions defined here will
+     * have been invoked by a row being activated (made active)
+     * elsewhere in the application.  But for the sequences initiated
+     * here, the rest of the application doesn't automatically know the
+     * active row has changed, so this method should be called to
+     * pass back that information during sequence operation.
+     *
+     * <p>Note this method does not (and must not, on pain of infinite
+     * recursion) trigger the results of an activation action as defined
+     * by this window.
+     *
+     * @param  lrow  new active row
+     */
+    private void updateActiveRow( long lrow ) {
+        tcModel_.fireModelChanged( TopcatEvent.ROW, new Long( lrow ) );
+    }
+
     /**
      * Adds a new entry to the list of currently configured/configurable
      * activation actions.
@@ -792,6 +822,7 @@ public class ActivationWindow extends AuxWindow {
         singleSeqAct_.configure();
         allSeqAct_.configure();
         cancelSeqAct_.configure();
+        seqPauser_.configure();
     }
 
     /**
@@ -868,6 +899,8 @@ public class ActivationWindow extends AuxWindow {
             NopActivationType.INSTANCE,
             new TopcatSkyPosActivationType(),
             new SendSkyPosActivationType(),
+            new ViewHips2fitsActivationType(),
+            new SendHips2fitsActivationType(),
             new InvokeDatalinkActivationType(),
             new ViewDatalinkActivationType(),
             new ViewImageActivationType(),
@@ -881,6 +914,7 @@ public class ActivationWindow extends AuxWindow {
             new CutoutActivationType(),
             new DownloadActivationType(),
             new BrowserActivationType(),
+            new DelayActivationType(),
             new JelActivationType(),
             new ShellActivationType(),
             new SendIndexActivationType( true ),
@@ -888,6 +922,63 @@ public class ActivationWindow extends AuxWindow {
         return list.toArray( new ActivationType[ 0 ] );
     }
 
+    /**
+     * Manages pausing of a programmed sequence of activation actions.
+     * The main job of this class is to mediate between activities on
+     * the Event Dispatch Thread whose sequence is ensured by the
+     * single-threaded nature of the GUI and a lock object that may
+     * be accessed from different threads.
+     */
+    private class SequencePauser {
+        private final Object lock_;
+        private final ToggleButtonModel model_;
+        private boolean isPaused_;
+        
+        SequencePauser() {
+            lock_ = this;
+            model_ = new ToggleButtonModel( "Pause Sequence",
+                                            ResourceIcon.PAUSE_SEQ,
+                                            "Pause (or unpause) a running "
+                                          + "sequence of actions" );
+            model_.setSelected( false );
+            model_.addChangeListener( new ChangeListener() {
+                public void stateChanged( ChangeEvent evt ) {
+                    boolean isSelected = model_.isSelected();
+                    synchronized ( lock_ ) {
+                        if ( isPaused_ != isSelected ) {
+                            isPaused_ = isSelected;
+                            lock_.notifyAll();
+                        }
+                    }
+                }
+            } );
+            configure();
+        }
+
+        /**
+         * Will block until this object's button model is no longer
+         * in the paused state.
+         */
+        public void waitIfPaused() throws InterruptedException {
+            synchronized ( lock_ ) {
+                while ( isPaused_ ) {
+                    lock_.wait();
+                }
+            }
+        }
+
+        /** 
+         * Configure for current state.  Should be called if anything,
+         * especially anything that may affect the enabledness, changes.
+         */
+        public void configure() {
+            model_.setEnabled( sequenceQueue_ != null );
+            if ( sequenceQueue_ == null ) {
+                model_.setSelected( false );
+            }
+        }
+    }
+
     /**
      * Invokes the currently selected action for the
      * most recently-activated row.
@@ -1088,21 +1179,36 @@ public class ActivationWindow extends AuxWindow {
                                   final ActivationEntry entry,
                                   final Activator activator ) {
             ViewerTableModel viewModel = tcModel_.getViewModel();
-            BoundedRangeModel progModel =
+            final BoundedRangeModel progModel =
                 new DefaultBoundedRangeModel( 0, 0, 0,
                                               viewModel.getRowCount() );
-            progBar_.setModel( progModel );
+            SwingUtilities.invokeLater( new Runnable() {
+                public void run() {
+                    progBar_.setModel( progModel );
+                }
+            } );
             try {
                 int ir = 0;
                 for ( Iterator<Long> it = viewModel.getRowIndexIterator();
                       it.hasNext() && ! queue.isShutdown(); ) {
+                    seqPauser_.waitIfPaused();
                     final long lrow = it.next().longValue();
+                    SwingUtilities.invokeLater( new Runnable() {
+                        public void run() {
+                            updateActiveRow( lrow );
+                        }
+                    } );
                     queue.submit( new Runnable() {
                         public void run() {
                             entry.activateRowSync( activator, lrow, meta_ );
                         }
                     } ).get();  // wait for completion
-                    progModel.setValue( ++ir );
+                    final int ir0 = ++ir;
+                    SwingUtilities.invokeLater( new Runnable() {
+                        public void run() {
+                            progModel.setValue( ir0 );
+                        }
+                    } );
                 }
             }
             catch ( InterruptedException e ) {
@@ -1199,38 +1305,52 @@ public class ActivationWindow extends AuxWindow {
                 runSequence( final ExecutorService queue,
                              final Map<ActivationEntry,Activator> activators ) {
             ViewerTableModel viewModel = tcModel_.getViewModel();
-            BoundedRangeModel progModel =
+            final BoundedRangeModel progModel =
                 new DefaultBoundedRangeModel( 0, 0, 0,
                                               viewModel.getRowCount() );
-            progBar_.setModel( progModel );
+            SwingUtilities.invokeLater( new Runnable() {
+                public void run() {
+                    progBar_.setModel( progModel );
+                }
+            } );
             try {
 
                 /* Step through each row of the table. */
                 int ir = 0;
                 for ( Iterator<Long> it = viewModel.getRowIndexIterator();
                       it.hasNext() && ! queue.isShutdown(); ) {
-                     final long lrow = it.next().longValue();
+                    seqPauser_.waitIfPaused();
+                    final long lrow = it.next().longValue();
+                    SwingUtilities.invokeLater( new Runnable() {
+                        public void run() {
+                            updateActiveRow( lrow );
+                        }
+                    } );
 
-                     /* Prepare a list of all the actions to be invoked. */
-                     Collection<Callable<Void>> jobs =
-                         new ArrayList<Callable<Void>>();
-                     for ( Map.Entry<ActivationEntry,Activator> e :
-                           activators.entrySet() ) {
-                         final ActivationEntry entry = e.getKey();
-                         final Activator activator = e.getValue();
-                         jobs.add( new Callable<Void>() {
-                             public Void call() {
-                                 entry.activateRowSync( activator, lrow,
-                                                        meta_ );
-                                 return null;
-                             }
-                         } );
-                     }
+                    /* Prepare a list of all the actions to be invoked. */
+                    Collection<Callable<Void>> jobs =
+                        new ArrayList<Callable<Void>>();
+                    for ( Map.Entry<ActivationEntry,Activator> e :
+                          activators.entrySet() ) {
+                        final ActivationEntry entry = e.getKey();
+                        final Activator activator = e.getValue();
+                        jobs.add( new Callable<Void>() {
+                            public Void call() {
+                                entry.activateRowSync( activator, lrow, meta_ );
+                                return null;
+                            }
+                        } );
+                    }
 
-                     /* Invoke them all concurrently, waiting until
-                      * all are complete before moving on to the next row. */
-                     queue.invokeAll( jobs );
-                     progModel.setValue( ++ir );
+                    /* Invoke them all concurrently, waiting until
+                     * all are complete before moving on to the next row. */
+                    queue.invokeAll( jobs );
+                    final int ir0 = ++ir;
+                    SwingUtilities.invokeLater( new Runnable() {
+                        public void run() {
+                            progModel.setValue( ir0 );
+                        }
+                    } );
                 }
             }
             catch ( InterruptedException e ) {
