@@ -4,15 +4,16 @@ import java.awt.Desktop;
 import java.net.URL;
 import java.util.ArrayList;
 import java.util.List;
-import javax.swing.Box;
 import javax.swing.JComboBox;
-import javax.swing.JComponent;
-import javax.swing.JLabel;
 import uk.ac.starlink.table.ColumnData;
+import uk.ac.starlink.table.gui.LabelledComponentStack;
+import uk.ac.starlink.topcat.AbstractHtmlPanel;
 import uk.ac.starlink.topcat.HtmlWindow;
 import uk.ac.starlink.topcat.Outcome;
 import uk.ac.starlink.topcat.Safety;
 import uk.ac.starlink.topcat.TopcatUtils;
+import uk.ac.starlink.ttools.calc.WebMapper;
+import uk.ac.starlink.util.gui.ShrinkWrapper;
 
 /**
  * ActivationType for displaying a resource in a browser.
@@ -27,8 +28,7 @@ public class BrowserActivationType implements ActivationType {
     }
 
     public String getDescription() {
-        return "Load the resource in a file or URL column"
-             + " into an external web browser";
+        return "Load an associated resource into a web browser";
     }
 
     public ActivatorConfigurator createConfigurator( TopcatModelInfo tinfo ) {
@@ -36,7 +36,8 @@ public class BrowserActivationType implements ActivationType {
     }
 
     public Suitability getSuitability( TopcatModelInfo tinfo ) {
-        return tinfo.tableHasFlag( ColFlag.HTML )
+        return tinfo.tableHasFlag( ColFlag.HTML ) ||
+               tinfo.tableHasFlag( ColFlag.WEBREF )
              ? Suitability.SUGGESTED
              : tinfo.getUrlSuitability();
     }
@@ -44,9 +45,12 @@ public class BrowserActivationType implements ActivationType {
     /**
      * Implementation that displays a URL in a general purpose web browser.
      */
+    @SuppressWarnings({"unchecked","rawtypes"})
     private static class BrowserColumnConfigurator
                          extends UrlColumnConfigurator {
+        private final JComboBox mapperChooser_;
         private final JComboBox browserChooser_;
+        private static final String WEBMAPPER_KEY = "webMapper";
         private static final String BROWSER_KEY = "browser";
 
         /**
@@ -57,31 +61,43 @@ public class BrowserActivationType implements ActivationType {
          */
         BrowserColumnConfigurator( TopcatModelInfo tinfo, Browser[] browsers ) {
             super( tinfo, "Web Page",
-                   new ColFlag[] { ColFlag.HTML, ColFlag.URL, } );
-            JComponent queryPanel = getQueryPanel();
+                   new ColFlag[] { ColFlag.HTML, ColFlag.WEBREF,
+                                   ColFlag.URL, } );
+            setLocationLabel( "Resource Identifier" );
+            mapperChooser_ = new JComboBox();
+            for ( WebMapper mapper : WebMapper.getMappers() ) {
+                mapperChooser_.addItem( mapper );
+            }
+            mapperChooser_.addActionListener( getActionForwarder() );
+
             browserChooser_ = new JComboBox();
             for ( Browser b : browsers ) {
                 browserChooser_.addItem( b );
             }
             browserChooser_.addActionListener( getActionForwarder() );
-            JLabel browserLabel = new JLabel( "Browser Type: " );
-            JComponent browserBox = Box.createHorizontalBox();
-            browserBox.add( browserLabel );
-            browserBox.add( browserChooser_ );
-            queryPanel.add( Box.createVerticalStrut( 5 ) );
-            queryPanel.add( browserBox );
+
+            LabelledComponentStack stack = new LabelledComponentStack();
+            stack.addLine( "Identifier Type", mapperChooser_ );
+            stack.addLine( "Browser", browserChooser_ );
+            getQueryPanel().add( stack );
         }
 
         protected Activator createActivator( ColumnData cdata ) {
-            final Object browser = browserChooser_.getSelectedItem();
+            final WebMapper mapper =
+                (WebMapper) mapperChooser_.getSelectedItem();
+            final Browser browser =
+                (Browser) browserChooser_.getSelectedItem();
             final String label = getWindowLabel( cdata );
-            return browser instanceof Browser
-                 ? new UrlColumnActivator( cdata, false ) {
-                       protected Outcome activateUrl( URL url, long lrow ) {
-                           return ((Browser) browser).browse( url, label );
-                       }
-                   }
-                 : null;
+            return new LocationColumnActivator( cdata, false ) {
+                protected Outcome activateLocation( String loc, long lrow ) {
+                    assert loc != null && loc.trim().length() > 0;
+                    URL url = mapper.toUrl( loc );
+                    return url == null
+                         ? Outcome.failure( "Not " + mapper.getName()
+                                          + ": " + loc )
+                         : browser.browse( url, label );
+                }
+            };
         }
 
         protected String getConfigMessage( ColumnData cdata ) {
@@ -96,12 +112,14 @@ public class BrowserActivationType implements ActivationType {
 
         public ConfigState getState() {
             ConfigState state = getUrlState();
+            state.saveSelection( WEBMAPPER_KEY, mapperChooser_ );
             state.saveSelection( BROWSER_KEY, browserChooser_ );
             return state;
         }
 
         public void setState( ConfigState state ) {
             setUrlState( state );
+            state.restoreSelection( WEBMAPPER_KEY, mapperChooser_ );
             state.restoreSelection( BROWSER_KEY, browserChooser_ );
         }
     }
@@ -113,11 +131,28 @@ public class BrowserActivationType implements ActivationType {
      */
     private final Browser[] createBrowserList() {
         List<Browser> list = new ArrayList<Browser>();
+        if ( AbstractHtmlPanel.hasJavaFx() ) {
+            list.add( new BasicBrowser( "JavaFX browser" ) {
+                AbstractHtmlPanel createHtmlPanel() {
+                    AbstractHtmlPanel panel =
+                        AbstractHtmlPanel.createFxPanel();
+                    if ( panel == null ) {
+                        assert false; 
+                        panel = AbstractHtmlPanel.createSwingPanel();
+                    }
+                    return panel;
+                }
+            } );
+        }
+        list.add( new BasicBrowser( "basic browser" ) {
+            AbstractHtmlPanel createHtmlPanel() {
+                return AbstractHtmlPanel.createSwingPanel();
+            }
+        } );
         Desktop desktop = TopcatUtils.getBrowserDesktop();
         if ( desktop != null ) {
             list.add( new DesktopBrowser( desktop ) );
         }
-        list.add( new BasicBrowser() );
         return list.toArray( new Browser[ 0 ] );
     }
 
@@ -150,10 +185,10 @@ public class BrowserActivationType implements ActivationType {
     /**
      * Internally implemented HTML display window.
      */
-    private static class BasicBrowser extends Browser {
+    private static abstract class BasicBrowser extends Browser {
         private HtmlWindow htmlWin_;
-        BasicBrowser() {
-            super( "basic browser" );
+        BasicBrowser( String name ) {
+            super( name );
         }
         public Outcome browse( URL url, String label ) {
             HtmlWindow win = getHtmlWindow( label );
@@ -167,7 +202,7 @@ public class BrowserActivationType implements ActivationType {
         }
         private HtmlWindow getHtmlWindow( String label ) {
             if ( htmlWin_ == null ) {
-                htmlWin_ = new HtmlWindow( null );
+                htmlWin_ = new HtmlWindow( null, createHtmlPanel() );
             }
             htmlWin_.setTitle( label );
             if ( ! htmlWin_.isShowing() ) {
@@ -175,6 +210,13 @@ public class BrowserActivationType implements ActivationType {
             }
             return htmlWin_;
         }
+
+        /**
+         * Returns an AbstractHtmlPanel implementation.
+         *
+         * @return  html panel, not null
+         */
+        abstract AbstractHtmlPanel createHtmlPanel();
     }
 
     /**
