@@ -65,7 +65,7 @@ public class CutoutActivationType implements ActivationType {
     }
 
     public Suitability getSuitability( TopcatModelInfo tinfo ) {
-        return tinfo.getSkySuitability();
+        return Suitability.AVAILABLE;
     }
 
     public ActivatorConfigurator createConfigurator( TopcatModelInfo tinfo ) {
@@ -75,6 +75,7 @@ public class CutoutActivationType implements ActivationType {
     /**
      * Configurator for use with CutoutActivationType.
      */
+    @SuppressWarnings({"unchecked","rawtypes"})
     private static class CutoutConfigurator extends SkyPosConfigurator {
 
         private final TopcatModel tcModel_;
@@ -119,8 +120,9 @@ public class CutoutActivationType implements ActivationType {
             final CutoutService serv = getSelectedService();
             final int npix = npixSelector_.getValue();
             final int tableId = tcModel_.getID();
-            return new SkyPosActivator( raData, decData, false ) {
-                protected Outcome useSkyPos( double raDeg, double decDeg ) {
+            return new SkyPosActivator( raData, decData, false, true ) {
+                protected Outcome useSkyPos( double raDeg, double decDeg,
+                                             long lrow ) {
                     serv.displayCutout( tableId, raDeg, decDeg, npix );
                     return Outcome.success();
                 }
