@@ -25,6 +25,7 @@ import uk.ac.starlink.topcat.Outcome;
 import uk.ac.starlink.topcat.Safety;
 import uk.ac.starlink.topcat.TopcatModel;
 import uk.ac.starlink.topcat.TopcatUtils;
+import uk.ac.starlink.util.gui.ShrinkWrapper;
 
 /**
  * ActivationType for displaying an image in the internal viewer.
@@ -73,6 +74,7 @@ public class GenericViewImageActivationType implements ActivationType {
     /**
      * Configurator implementation for URLs pointing to images.
      */
+    @SuppressWarnings({"unchecked","rawtypes"})
     private static class ImageColumnConfigurator extends UrlColumnConfigurator {
         final TopcatModel tcModel_;
         final boolean isRegion_;
@@ -115,8 +117,9 @@ public class GenericViewImageActivationType implements ActivationType {
                 queryPanel.add( Box.createVerticalStrut( 5 ) );
             }
             if ( hasViewerChoice_ ) {
-                getQueryPanel().add( new LineBox( "Image Viewer",
-                                                  viewerSelector_ ) );
+                getQueryPanel()
+               .add( new LineBox( "Image Viewer",
+                                  new ShrinkWrapper( viewerSelector_ ) ) );
             }
         }
         public Activator createActivator( ColumnData locCdata ) {
@@ -294,7 +297,7 @@ public class GenericViewImageActivationType implements ActivationType {
                     final ImageWindow imwin = getImageWindow( label );
                     final BufferedImage image;
                     try {
-                        image = imwin.createImage( loc, allowSystem_ );
+                        image = ImageWindow.createImage( loc, allowSystem_ );
                     }
                     catch ( IOException e ) {
                         return Outcome.failure( e );
@@ -315,11 +318,17 @@ public class GenericViewImageActivationType implements ActivationType {
                             imwin.setImagePoint( image, point );
                         }
                     } );
-                    String msg = ( point == null
-                                   ? "(no position)"
-                                   : "(" + point.x + ", " + point.y + ")" )
-                               + ": " + loc;
-                    return Outcome.success( msg );
+                    StringBuffer sbuf = new StringBuffer();
+                    if ( point != null ) {
+                        sbuf.append( "(" )
+                            .append( point.x )
+                            .append( ", " )
+                            .append( point.y )
+                            .append( ")" )
+                            .append( ": " );
+                    }
+                    sbuf.append( loc );
+                    return Outcome.success( sbuf.toString() );
                 }
             };
         }
@@ -464,6 +473,7 @@ public class GenericViewImageActivationType implements ActivationType {
     /**
      * Component for choosing a numeric table column.
      */
+    @SuppressWarnings({"unchecked","rawtypes"})
     private static class NumberSelector {
         final String label_;
         final ColumnDataComboBoxModel model_;
