@@ -9,7 +9,7 @@ import uk.ac.starlink.topcat.ActionForwarder;
 import uk.ac.starlink.topcat.LineBox;
 import uk.ac.starlink.topcat.Outcome;
 import uk.ac.starlink.topcat.Safety;
-import uk.ac.starlink.topcat.TopcatModel;
+import uk.ac.starlink.util.gui.ShrinkWrapper;
 
 /**
  * ActivationType for displaying a FITS image in an external viewer.
@@ -41,8 +41,8 @@ public class SendImageActivationType implements ActivationType {
     /**
      * Configurator implementation for URLs pointing to FITS images.
      */
+    @SuppressWarnings({"unchecked","rawtypes"})
     private static class ImageColumnConfigurator extends UrlColumnConfigurator {
-        final TopcatModel tcModel_;
         final SampSender imageSender_;
         final ListModel clientListModel_;
 
@@ -56,7 +56,6 @@ public class SendImageActivationType implements ActivationType {
         ImageColumnConfigurator( TopcatModelInfo tinfo ) {
             super( tinfo, "Image",
                    new ColFlag[] { ColFlag.IMAGE, ColFlag.URL, } );
-            tcModel_ = tinfo.getTopcatModel();
             imageSender_ = new SampSender( IMAGE_MTYPE );
             ActionForwarder forwarder = getActionForwarder();
             clientListModel_ = imageSender_.getClientListModel();
@@ -65,8 +64,9 @@ public class SendImageActivationType implements ActivationType {
             JComboBox viewerSelector =
                  new JComboBox( imageSender_.getClientSelectionModel() );
             viewerSelector.addActionListener( forwarder );
-            getQueryPanel().add( new LineBox( "Image Viewer",
-                                              viewerSelector ) );
+            getQueryPanel()
+           .add( new LineBox( "Image Viewer",
+                              new ShrinkWrapper( viewerSelector ) ) );
         }
 
         protected Activator createActivator( final ColumnData cdata ) {
