@@ -51,10 +51,11 @@ import uk.ac.starlink.util.gui.ShrinkWrapper;
  * @author   Mark Taylor
  * @since    15 Mar 2013
  */
+@SuppressWarnings({"unchecked","rawtypes"})
 public class FormStylePanel extends JPanel {
 
     private final Configger plotConfigger_;
-    private final Factory<Plotter> plotterFact_;
+    private final Factory<Plotter<?>> plotterFact_;
     private final SubsetConfigManager subManager_;
     private final SubsetStack subStack_;
     private final TopcatModel tcModel_;
@@ -77,8 +78,8 @@ public class FormStylePanel extends JPanel {
      * @param  subStack    controls/display per-subset visibility
      * @param  tcModel   topcat model whose subsets are being configured
      */
-    public FormStylePanel( ConfigKey[] keys, Configger plotConfigger,
-                           Factory<Plotter> plotterFact,
+    public FormStylePanel( ConfigKey<?>[] keys, Configger plotConfigger,
+                           Factory<Plotter<?>> plotterFact,
                            SubsetConfigManager subManager,
                            SubsetStack subStack, TopcatModel tcModel ) {
         setLayout( new BoxLayout( this, BoxLayout.Y_AXIS ) );
@@ -252,7 +253,7 @@ public class FormStylePanel extends JPanel {
      * Accepts plot reports indexed by subset, and passes them on
      * to the relevant specifiers.
      *
-     * @param   reports   map of subset->plot report maps for the plot layers
+     * @param   reports   map of subset-&gt;plot report maps for the plot layers
      *                    generated by this panel
      */
     public void submitReports( Map<RowSubset,ReportMap> reports ) {
