@@ -12,6 +12,7 @@ import java.util.logging.Logger;
 import javax.swing.Action;
 import javax.swing.Icon;
 import uk.ac.starlink.table.ColumnData;
+import uk.ac.starlink.table.HealpixTableInfo;
 import uk.ac.starlink.topcat.BasicAction;
 import uk.ac.starlink.topcat.ColumnDataComboBoxModel;
 import uk.ac.starlink.topcat.ResourceIcon;
@@ -32,6 +33,7 @@ import uk.ac.starlink.ttools.plot2.data.Coord;
 import uk.ac.starlink.ttools.plot2.data.CoordGroup;
 import uk.ac.starlink.ttools.plot2.data.FloatingCoord;
 import uk.ac.starlink.ttools.plot2.data.Input;
+import uk.ac.starlink.ttools.plot2.layer.HealpixPlotter;
 import uk.ac.starlink.util.Loader;
 
 /**
@@ -43,17 +45,17 @@ import uk.ac.starlink.util.Loader;
  * @author   Mark Taylor
  * @since    15 Mar 2013
  */
-public class GroupControlManager implements ControlManager {
+public class GroupControlManager<P,A> implements ControlManager {
 
     private final ControlStack stack_;
-    private final PlotType plotType_;
-    private final PlotTypeGui plotTypeGui_;
+    private final PlotType<P,A> plotType_;
+    private final PlotTypeGui<P,A> plotTypeGui_;
     private final TypedListModel<TopcatModel> tablesModel_;
     private final ZoneFactory zfact_;
     private final MultiConfigger baseConfigger_;
     private final TopcatListener tcListener_;
     private final NextSupplier nextSupplier_;
-    private final Map<CoordsType,List<Plotter>> plotterMap_;
+    private final Map<CoordsType,List<Plotter<?>>> plotterMap_;
     private final Action[] stackActs_;
 
     private static final Logger logger_ =
@@ -82,8 +84,8 @@ public class GroupControlManager implements ControlManager {
      *                     for it to listen to whatever is the currently
      *                     selected TopcatModel
      */
-    public GroupControlManager( ControlStack stack, PlotType plotType,
-                                PlotTypeGui plotTypeGui,
+    public GroupControlManager( ControlStack stack, PlotType<P,A> plotType,
+                                PlotTypeGui<P,A> plotTypeGui,
                                 TypedListModel<TopcatModel> tablesModel,
                                 ZoneFactory zfact, MultiConfigger baseConfigger,
                                 TopcatListener tcListener ) {
@@ -101,15 +103,15 @@ public class GroupControlManager implements ControlManager {
 
         /* Split the list up by the number of positional coordinates
          * they have. */
-        plotterMap_ = new LinkedHashMap<CoordsType,List<Plotter>>();
+        plotterMap_ = new LinkedHashMap<CoordsType,List<Plotter<?>>>();
         for ( CoordsType ctyp : CoordsType.values() ) {
-            plotterMap_.put( ctyp, new ArrayList<Plotter>() );
+            plotterMap_.put( ctyp, new ArrayList<Plotter<?>>() );
         }
-        for ( Plotter plotter : plotType_.getPlotters() ) {
+        for ( Plotter<?> plotter : plotType_.getPlotters() ) {
             CoordsType ctyp = CoordsType.getInstance( plotter );
             plotterMap_.get( ctyp ).add( plotter );
         }
-        for ( Plotter plotter :
+        for ( Plotter<?> plotter :
               Loader.getClassInstances( PLOTTERS_PROP, Plotter.class ) ) {
             CoordsType ctyp = CoordsType.getInstance( plotter );
             plotterMap_.get( ctyp ).add( plotter );
@@ -126,6 +128,7 @@ public class GroupControlManager implements ControlManager {
                 stackActList.add( new LayerControlAction( actName,
                                                           ctyp.getIcon(),
                                                           actDescrip,
+                                                          (Plotter) null,
                                                           stack_ ) {
                     public LayerControl createLayerControl() {
                         return createGroupControl( ctyp0, true );
@@ -136,7 +139,7 @@ public class GroupControlManager implements ControlManager {
 
         /* Add single controls for miscellaneous plotters. */
         assert CoordsType.MISC.getIcon() == null;
-        for ( Plotter plotter : plotterMap_.get( CoordsType.MISC ) ) {
+        for ( Plotter<?> plotter : plotterMap_.get( CoordsType.MISC ) ) {
             Action stackAct =
                 LayerControlAction
                .createPlotterAction( plotter, stack, tablesModel_, zfact_,
@@ -158,11 +161,35 @@ public class GroupControlManager implements ControlManager {
     }
 
     public Control createDefaultControl( TopcatModel tcModel ) {
-        Action act0 = stackActs_[ 0 ];
-        for ( int ia = 0; ia < stackActs_.length; ia++ ) {
-            if ( stackActs_[ ia ] instanceof LayerControlAction ) {
-                LayerControlAction cact = (LayerControlAction) stackActs_[ ia ];
-                LayerControl control = cact.createLayerControl();
+
+        /* For the special case where the table is known to contain HEALPix
+         * indices, and one of the layer controls can plot those, use that
+         * control.  In most cases, the other controls will not be appropriate
+         * for such a table. */
+        if ( tcModel != null &&
+             HealpixTableInfo.isHealpix( tcModel.getDataModel()
+                                                .getParameters() ) ) {
+            for ( Action stackAct : stackActs_ ) {
+                if ( stackAct instanceof LayerControlAction ) {
+                    LayerControlAction cact = (LayerControlAction) stackAct;
+                    if ( cact.getPlotter() instanceof HealpixPlotter ) {
+                        LayerControl control = cact.createLayerControl();
+                        assert control instanceof HealpixLayerControl;
+                        if ( control instanceof HealpixLayerControl ) {
+                            ((HealpixLayerControl) control)
+                                                  .setTopcatModel( tcModel );
+                            return control;
+                        }
+                    }
+                }
+            }
+        }
+
+        /* Otherwise, just pick the first control. */
+        for ( Action stackAct : stackActs_ ) {
+            if ( stackAct instanceof LayerControlAction ) {
+                LayerControl control =
+                    ((LayerControlAction) stackAct).createLayerControl();
                 if ( control instanceof FormLayerControl ) {
                     ((FormLayerControl) control).setTopcatModel( tcModel );
                 }
@@ -172,7 +199,7 @@ public class GroupControlManager implements ControlManager {
         return null;
     }
 
-    public void addLayer( LayerCommand lcmd ) throws LayerException {
+    public void addLayer( LayerCommand<?> lcmd ) throws LayerException {
         logger_.info( "Add layer: " + lcmd );
         getGroupControl( lcmd ).addLayer( lcmd );
     }
@@ -187,7 +214,7 @@ public class GroupControlManager implements ControlManager {
      * @return  control in the stack for which <code>addLayer(lcmd)</code>
      *          will work
      */
-    private MultiFormLayerControl getGroupControl( LayerCommand lcmd )
+    private MultiFormLayerControl getGroupControl( LayerCommand<?> lcmd )
             throws LayerException {
         ControlStackModel stackModel = stack_.getStackModel();
 
@@ -219,7 +246,7 @@ public class GroupControlManager implements ControlManager {
      * @return  true iff <code>control.addLayer(lcmd)</code> will work
      */
     private static boolean isCompatible( MultiFormLayerControl control,
-                                         LayerCommand lcmd ) {
+                                         LayerCommand<?> lcmd ) {
 
         /* Note the implementation of this method is closely tied to the
          * implementation of MultiFormLayerControl.addLayer. */
@@ -277,7 +304,7 @@ public class GroupControlManager implements ControlManager {
      * @param  lcmd  layer specification
      * @return  new control for which <code>addLayer(lcmd)</code> will work
      */
-    private MultiFormLayerControl createGroupControl( LayerCommand lcmd )
+    private MultiFormLayerControl createGroupControl( LayerCommand<?> lcmd )
             throws LayerException {
 
         /* Create the control. */
@@ -332,7 +359,7 @@ public class GroupControlManager implements ControlManager {
      */
     private MultiFormLayerControl createGroupControl( CoordsType ctyp,
                                                       boolean autoPlot ) {
-        List<Plotter> plotterList = plotterMap_.get( ctyp );
+        List<Plotter<?>> plotterList = plotterMap_.get( ctyp );
         if ( plotterList != null && plotterList.size() > 0 ) {
             PositionCoordPanel coordPanel =
                 ctyp.createPositionCoordPanel( plotType_, plotTypeGui_ );
@@ -345,7 +372,7 @@ public class GroupControlManager implements ControlManager {
                                            autoPop, nextSupplier_, tcListener_,
                                            ctyp.getIcon(),
                                            plotterList
-                                          .toArray( new Plotter[ 0 ] ),
+                                          .toArray( new Plotter<?>[ 0 ] ),
                                            zoneConfigger );
             if ( autoPlot ) {
                 control.addDefaultLayer();
@@ -366,28 +393,37 @@ public class GroupControlManager implements ControlManager {
 
         /** Plotter with a single positional coordinate. */
         SINGLE_POS( ResourceIcon.PLOT_DATA, "Position", "positional", true ) {
-            public PositionCoordPanel
-                    createPositionCoordPanel( PlotType plotType,
-                                              PlotTypeGui plotTypeGui ) {
+            public <P,A> PositionCoordPanel
+                    createPositionCoordPanel( PlotType<P,A> plotType,
+                                              PlotTypeGui<P,A> plotTypeGui ) {
                 return plotTypeGui.createPositionCoordPanel( 1 );
             }
         },
 
         /** Plotter with two positional coordinates. */
-        DOUBLE_POS( ResourceIcon.PLOT_PAIR, "Pair", "pair position", false ) {
-            public PositionCoordPanel
-                    createPositionCoordPanel( PlotType plotType,
-                                              PlotTypeGui plotTypeGui ) {
+        DOUBLE_POS( ResourceIcon.PLOT_PAIR, "Pair", "pair position", true ) {
+            public <P,A> PositionCoordPanel
+                    createPositionCoordPanel( PlotType<P,A> plotType,
+                                              PlotTypeGui<P,A> plotTypeGui ) {
                 return plotTypeGui.createPositionCoordPanel( 2 );
             }
         },
 
+        /** Plotter with four positional coordinates. */
+        QUAD_POS( ResourceIcon.PLOT_QUAD, "Quad", "quadrilateral", true ) {
+            public <P,A> PositionCoordPanel
+                    createPositionCoordPanel( PlotType<P,A> plotType,
+                                              PlotTypeGui<P,A> plotTypeGui ) {
+                return plotTypeGui.createPositionCoordPanel( 4 );
+            }
+        },
+
         /** Histogram-like plotter. */
         WEIGHTED_HISTO( ResourceIcon.PLOT_HISTO, "Histogram",
                         "optionally weighted histogram", true ) {
-            public PositionCoordPanel
-                    createPositionCoordPanel( PlotType plotType,
-                                              PlotTypeGui plotTypeGui ) {
+            public <P,A> PositionCoordPanel
+                    createPositionCoordPanel( PlotType<P,A> plotType,
+                                              PlotTypeGui<P,A> plotTypeGui ) {
                 Coord[] coords = {
                     plotType.getPointDataGeoms()[ 0 ].getPosCoords()[ 0 ],
                     FloatingCoord.WEIGHT_COORD,
@@ -398,9 +434,9 @@ public class GroupControlManager implements ControlManager {
 
         /** Plotter not covered by other categories. */
         MISC( null, null, null, false ) {
-            public PositionCoordPanel
-                    createPositionCoordPanel( PlotType plotType,
-                                              PlotTypeGui plotTypeGui ) {
+            public <P,A> PositionCoordPanel
+                    createPositionCoordPanel( PlotType<P,A> plotType,
+                                              PlotTypeGui<P,A> plotTypeGui ) {
                 return null;
             }
         };
@@ -469,9 +505,9 @@ public class GroupControlManager implements ControlManager {
          * @param   plotType  plot specifics
          * @param   plotTypeGui  gui plot specifics
          */
-        public abstract PositionCoordPanel
-                createPositionCoordPanel( PlotType plotType,
-                                          PlotTypeGui plotTypeGui );
+        public abstract <P,A> PositionCoordPanel
+                createPositionCoordPanel( PlotType<P,A> plotType,
+                                          PlotTypeGui<P,A> plotTypeGui );
 
         /**
          * Categorises plotters in terms of this enum.
@@ -479,15 +515,34 @@ public class GroupControlManager implements ControlManager {
          * @param  plotter  plotter to categorise
          * @return  instance of this class corresponding to plotter, not null
          */
-        public static CoordsType getInstance( Plotter plotter ) {
+        public static CoordsType getInstance( Plotter<?> plotter ) {
             CoordGroup cgrp = plotter.getCoordGroup();
             int npos = cgrp.getPositionCount();
-            if ( npos == 1 ) {
+
+            /* Treat HealpixPlotter as a special case since although it has
+             * positional coordinates, they are not the standard coordinates
+             * for its plot type (it's a pixel index, not a lon/lat pair).
+             * This special handling is a bit messy and should really be
+             * generalised, but since it's the only such special case so far,
+             * it's not clear how best to do that generalisation.
+             * If other instances of this kind of requirement come up,
+             * consider this more carefully and generalise the handling
+             * as appropriate. */
+            if ( plotter instanceof HealpixPlotter ) {
+                return CoordsType.MISC;
+            }
+
+            /* For other layer types, examine their declared characteristics
+             * to decide how they are categorised. */
+            else if ( npos == 1 ) {
                 return CoordsType.SINGLE_POS;
             }
             else if ( npos == 2 ) {
                 return CoordsType.DOUBLE_POS;
             }
+            else if ( npos == 4 ) {
+                return CoordsType.QUAD_POS;
+            }
             else if ( cgrp.isSinglePartialPosition() &&
                       cgrp.getExtraCoords().length == 2 &&
                       cgrp.getExtraCoords()[ 1 ]
