@@ -44,13 +44,21 @@ public interface PlotTypeGui<P,A> {
      */
     boolean isPlanar();
 
+    /**
+     * Returns a list of figure drawing modes that can be used for graphically
+     * marking out shapes on the plot surface.
+     *
+     * @return  available figure modes; may be empty
+     */
+    public FigureMode[] getFigureModes();
+
     /**
      * Returns the GangerFactory used by this plot.
      * It controls how multi-zone plots are arranged.
      *
      * @return   ganger factory
      */
-    GangerFactory getGangerFactory();
+    GangerFactory<P,A> getGangerFactory();
 
     /**
      * Returns a new zone ID factory for use with this plot.
@@ -61,10 +69,19 @@ public interface PlotTypeGui<P,A> {
      */
     ZoneFactory createZoneFactory();
 
+    /**
+     * Returns an object that can characterise surfaces used by this plot type
+     * as hypercubes in data coordinate space.
+     * If it can't be done, null is returned.
+     *
+     * @return  Cartesian ranger for this plot type, or null
+     */
+    CartesianRanger getCartesianRanger();
+
     /**
      * Returns the help ID describing the navigation actions for this plot.
      *
      * @return  navigator help id
      */
-    public String getNavigatorHelpId();
+    String getNavigatorHelpId();
 }
