@@ -5,7 +5,6 @@ import java.awt.Component;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
-import uk.ac.starlink.table.ColumnData;
 import uk.ac.starlink.table.ValueInfo;
 import uk.ac.starlink.topcat.ColumnDataComboBoxModel;
 import uk.ac.starlink.topcat.TopcatModel;
@@ -13,7 +12,6 @@ import uk.ac.starlink.topcat.TypedListModel;
 import uk.ac.starlink.ttools.plot2.DataGeom;
 import uk.ac.starlink.ttools.plot2.GangerFactory;
 import uk.ac.starlink.ttools.plot2.PlotType;
-import uk.ac.starlink.ttools.plot2.PlotUtil;
 import uk.ac.starlink.ttools.plot2.SingleGanger;
 import uk.ac.starlink.ttools.plot2.config.ConfigKey;
 import uk.ac.starlink.ttools.plot2.config.Specifier;
@@ -84,14 +82,23 @@ public class SkyPlotWindow
             return false;
         }
 
-        public GangerFactory getGangerFactory() {
-            return SingleGanger.FACTORY;
+        public FigureMode[] getFigureModes() {
+            return SkyFigureMode.MODES;
+        }
+
+        public GangerFactory<SkySurfaceFactory.Profile,SkyAspect>
+                getGangerFactory() {
+            return SingleGanger.createFactory( PLOT_TYPE );
         }
 
         public ZoneFactory createZoneFactory() {
             return ZoneFactories.FIXED;
         } 
 
+        public CartesianRanger getCartesianRanger() {
+            return null;
+        }
+
         public String getNavigatorHelpId() {
             return "skyNavigation";
         }
@@ -107,8 +114,30 @@ public class SkyPlotWindow
     private static abstract class SkyPositionCoordPanel
             extends PositionCoordPanel {
 
+        private final int npos_;
         private final Specifier<SkySys> dataSysSpecifier_;
 
+        private static final String[] LONLAT = new String[] { "lon", "lat" };
+        private static final String[] RADEC = new String[] { "ra", "dec" };
+        private static final String[] RAJDEJ = new String[] { "raj", "dej" };
+        private static final CoordSpotter[] LONLAT_SPOTTERS = {
+            CoordSpotter.createUcdSpotter( "pos.eq", RADEC, false ),
+            CoordSpotter.createUcdSpotter( "pos.eq", RADEC, true ),
+            CoordSpotter.createUcdSpotter( "pos.ecliptic", LONLAT, false ),
+            CoordSpotter.createUcdSpotter( "pos.ecliptic", LONLAT, true ),
+            CoordSpotter.createUcdSpotter( "pos.galactic", LONLAT, false ),
+            CoordSpotter.createUcdSpotter( "pos.galactic", LONLAT, true ),
+            CoordSpotter.createUcdSpotter( "pos.bodyrc", LONLAT, false ),
+            CoordSpotter.createUcdSpotter( "pos.bodyrc", LONLAT, true ),
+            CoordSpotter.createUcdSpotter( "pos.earth", LONLAT, false ),
+            CoordSpotter.createUcdSpotter( "pos.earth", LONLAT, true ),
+            CoordSpotter.createNamePrefixSpotter( LONLAT, true ),
+            CoordSpotter.createNamePrefixSpotter( LONLAT, false ),
+            CoordSpotter.createNamePrefixSpotter( RADEC, true ),
+            CoordSpotter.createNamePrefixSpotter( RADEC, false ),
+            CoordSpotter.createNamePrefixSpotter( RAJDEJ, true ),
+        };
+
         /**
          * Constructor.
          *
@@ -117,7 +146,8 @@ public class SkyPlotWindow
         SkyPositionCoordPanel( int npos ) {
             super( multiplyCoords( SkyDataGeom.createGeom( null, null )
                                               .getPosCoords(), npos ),
-                   new ConfigKey[] { DATASYS_KEY } );
+                   new ConfigKey<?>[] { DATASYS_KEY } );
+            npos_ = npos;
             dataSysSpecifier_ =
                 getConfigSpecifier().getSpecifier( DATASYS_KEY );
         }
@@ -146,13 +176,40 @@ public class SkyPlotWindow
 
         @Override
         public void autoPopulate() {
-            ColumnDataComboBoxModel lonModel = getColumnSelector( 0, 0 );
-            ColumnDataComboBoxModel latModel = getColumnSelector( 0, 1 );
-            SkySys currentSys = dataSysSpecifier_.getSpecifiedValue();
-            SkySys sys = new ColPopulator( lonModel, latModel )
-                        .attemptPopulate( currentSys );
-            if ( sys != null && sys != currentSys ) {
-                dataSysSpecifier_.setSpecifiedValue( sys );
+
+            /* Override the default autoPopulate behaviour, which won't
+             * work well since we have coordinates with multiple components. */
+
+            /* Do some special handling for the (most common)
+             * single-position case: try to work out the data sky system
+             * as well as picking suitable columns. */
+            if ( npos_ == 1 ) {
+                ColumnDataComboBoxModel lonModel = getColumnSelector( 0, 0 );
+                ColumnDataComboBoxModel latModel = getColumnSelector( 0, 1 );
+                SkySys currentSys = dataSysSpecifier_.getSpecifiedValue();
+                SkySys sys = new ColPopulator( lonModel, latModel )
+                            .attemptPopulate( currentSys );
+                if ( sys != null && sys != currentSys ) {
+                    dataSysSpecifier_.setSpecifiedValue( sys );
+                }
+            }
+
+            /* Otherwise, just look for matched groups of lon/lat coords.
+             * This is less effort, but still better than nothing. */
+            else {
+                ValueInfo[] lonlatInfos =
+                    CoordSpotter
+                   .findCoordGroups( npos_,
+                                     getInfos( getColumnSelector( 0, 0 ) ),
+                                     LONLAT_SPOTTERS );
+                if ( lonlatInfos != null ) {
+                    for ( int ipos = 0; ipos < npos_; ipos++ ) {
+                        populate( getColumnSelector( ipos, 0 ),
+                                  lonlatInfos[ ipos * 2 + 0 ] );
+                        populate( getColumnSelector( ipos, 1 ),
+                                  lonlatInfos[ ipos * 2 + 1 ] );
+                    }
+                }
             }
         }
     }
@@ -180,9 +237,10 @@ public class SkyPlotWindow
             /* We expect that the models are selectors on the same list
              * of table columns.  If they are not, some of the implementation
              * assumptions of this class will fail. */
-            assert Arrays.equals( getInfoNames( getInfos( lonModel ) ),
-                                  getInfoNames( getInfos( latModel ) ) );
-            infos_ = getInfos( lonModel );
+            assert Arrays
+                  .equals( getInfoNames( CoordPanel.getInfos( lonModel ) ),
+                           getInfoNames( CoordPanel.getInfos( latModel ) ) );
+            infos_ = CoordPanel.getInfos( lonModel );
         }
 
         /**
@@ -211,8 +269,10 @@ public class SkyPlotWindow
             for ( SkySys sys : systems ) {
                 int[] pair = sys.getCoordPair( infos_ );
                 if ( pair != null ) {
-                    if ( populate( lonModel_, infos_[ pair[ 0 ] ] ) &&
-                         populate( latModel_, infos_[ pair[ 1 ] ] ) ) {
+                    if ( CoordPanel.populate( lonModel_,
+                                              infos_[ pair[ 0 ] ] ) &&
+                         CoordPanel.populate( latModel_,
+                                              infos_[ pair[ 1 ] ] ) ) {
                         return sys;
                     }
                     else {
@@ -223,49 +283,6 @@ public class SkyPlotWindow
             return null;
         }
 
-        /**
-         * Tries to find an item of a given combo box model matching a given
-         * metadata item.  If it finds it, it will set the selection and
-         * return true.
-         *
-         * @param   model   list model
-         * @param  info   template for selection value
-         * @return  true if selection was successfully performed
-         */
-        private static boolean populate( ColumnDataComboBoxModel model,
-                                         ValueInfo info ) {
-            for ( int i = 0; i < model.getSize(); i++ ) {
-                ColumnData cdata = model.getColumnDataAt( i );
-                if ( cdata != null &&
-                     infoMatches( cdata.getColumnInfo(), info ) ) {
-                    model.setSelectedItem( cdata );
-                    return true;
-                }
-            }
-            return false;
-        }
-
-        /**
-         * Returns a list of column metadata items for the items in a
-         * list model of columns.
-         *
-         * @param  model  column list model
-         * @return  list of valueinfos
-         */
-        private static ValueInfo[] getInfos( ColumnDataComboBoxModel model ) {
-            List<ValueInfo> list = new ArrayList<ValueInfo>();
-            for ( int i = 0; i < model.getSize(); i++ ) {
-                ColumnData cdata = model.getColumnDataAt( i );
-                if ( cdata != null ) {
-                    ValueInfo info = cdata.getColumnInfo();
-                    if ( info != null ) {
-                        list.add( info );
-                    }
-                }
-            }
-            return list.toArray( new ValueInfo[ 0 ] );
-        }
-
         /**
          * Returns a list of column names for a given list of colum metadata
          * items.
@@ -281,18 +298,5 @@ public class SkyPlotWindow
             }
             return names;
         }
-
-        /**
-         * Indicates whether two infos match.
-         * The criterion is that both name and UCD are the same.
-         *
-         * @param  info1  first item
-         * @param  info2  second item
-         * @return  true iff match
-         */
-        private static boolean infoMatches( ValueInfo info1, ValueInfo info2 ) {
-            return PlotUtil.equals( info1.getName(), info2.getName() )
-                && PlotUtil.equals( info1.getUCD(), info2.getUCD() );
-        }
     }
 }
