@@ -70,6 +70,7 @@ import uk.ac.starlink.vo.SkyPositionEntry;
  * @author   Thomas Boch
  * @since    19 Oct 2009
  */
+@SuppressWarnings({"unchecked","rawtypes"})
 public class VizierTableLoadDialog extends AbstractTableLoadDialog {
 
     private final ContentCoding coding_;
@@ -97,7 +98,10 @@ public class VizierTableLoadDialog extends AbstractTableLoadDialog {
      *         >http://vizier.u-strasbg.fr/vizier/mirrors.gml</a>.
      */
     public static final String[] SERVER_URLS = new String[] {
+        // Default site.
         "http://vizier.u-strasbg.fr/",
+
+        // Mirrors.
         "http://vizier.nao.ac.jp/",
         "http://vizier.hia.nrc.ca/",
         "http://vizier.ast.cam.ac.uk/",
@@ -106,6 +110,10 @@ public class VizierTableLoadDialog extends AbstractTableLoadDialog {
         "http://vizier.iucaa.in/",
         "http://vizier.china-vo.org/",
         "http://viziersaao.chpc.ac.za/",
+
+        // Experimental/beta services (no guarantees).
+        "http://viz-beta.u-strasbg.fr/",
+        "http://cdsarc.u-strasbg.fr/",
     };
 
     /**
@@ -377,7 +385,7 @@ public class VizierTableLoadDialog extends AbstractTableLoadDialog {
                     .addArgument( "-source", queryable.getQuerySource() )
                     .toString() );
         ubuf.append( encodeArg( "-oc.form", "dec" ) );
-        ubuf.append( encodeArg( "-out.meta", "DhuL" ) );
+        ubuf.append( encodeArg( "-out.meta", "Dhul" ) );
         boolean allRows = isAllRows();
         if ( ! allRows ) {
             ubuf.append( encodeArg( "-c", getTarget() ) );
